@@ -88,4 +88,6 @@ def read_values_from_array(query_columns_description: list, dis: DataInputStream
         elif dtype == "INT96":
             value_array.append(dis.read_utf())
 
+    if len(value_array) < 5:
+        print("stop here")
     return value_array
